@@ -6,7 +6,7 @@ from nwon_django_toolbox.exception_handler.get_error_response import (
 
 
 class ExceptionMiddleware(object):
-    def __init__(self, get_response=custom_get_response):
+    def __init__(self, get_response):
         self.get_response = get_response
 
     def __call__(self, request):
@@ -18,7 +18,7 @@ class ExceptionMiddleware(object):
                 status_code=response.status_code,
             )
 
-            return JsonResponse(response_data, status=response.status_code)
+            return HttpResponse(response_data, status=response.status_code)
 
         if response.status_code == 404:
             response_data = custom_get_response(
@@ -26,6 +26,6 @@ class ExceptionMiddleware(object):
                 status_code=response.status_code,
             )
 
-            return JsonResponse(response, status=response.status_code)
+            return HttpResponse(response_data, status=response.status_code)
 
         return response
