@@ -1,4 +1,5 @@
 import copy
+import json
 from typing import List, Optional, Type
 
 import jsonref
@@ -42,9 +43,9 @@ class PydanticJsonFieldSerializer(JSONField, Field):
         for model in self.pydantic_models:
             try:
                 if isinstance(value, dict):
-                    return model.parse_obj(value).dict()
+                    return json.loads(model.parse_obj(value).json())
                 else:
-                    return model.parse_raw(value).dict()
+                    return json.loads(model.parse_raw(value).json())
             except PydanticValidationError:
                 pass
 
