@@ -1,17 +1,14 @@
-from typing import Optional, Type
+from typing import Optional
 
 from django.db.models import Model
 from django.urls import reverse
 from django.utils.html import format_html
 
 from nwon_django_toolbox.settings import NWON_DJANGO_SETTINGS
-from nwon_django_toolbox.typings.model_type import ModelType
 from nwon_django_toolbox.url_helper.url_helper import base_name_from_model
 
 
-def formatted_django_admin_link(
-    model: ModelType[Model], application: str = "tamoc"
-) -> str:
+def formatted_django_admin_link(model: Model, application: str = "tamoc") -> str:
     if application is None:
         raise Exception(
             "In order to use django_admin_link_for_model you need to set application_name in the NWON_DJANGO settings"
@@ -22,7 +19,7 @@ def formatted_django_admin_link(
 
 
 def django_admin_link_for_model(
-    model: Type[Model],
+    model: Model,
     application: Optional[str] = NWON_DJANGO_SETTINGS.application_name,
 ) -> str:
     if application is None:
@@ -31,7 +28,7 @@ def django_admin_link_for_model(
         )
 
     return reverse(
-        f"admin:{application}_{base_name_from_model(model.__class__)}_change",
+        f"admin:{application}_{base_name_from_model(model)}_change",
         args=(model.pk,),
     )
 
